# `cesium`: Open-Source Platform for Time Series Inference

## Summary

`cesium` is an open source library that allows users to:

- extract features from raw time series data ([see list](http://cesium-ml.org/docs/feature_table.html)),
- build machine learning models from these features, and
- generate predictions for new data.

More information and
[examples](http://cesium-ml.org/docs/auto_examples/index.html) can be
found on our [home page](http://cesium-ml.org).

## Installation

```
pip install cesium
```

## [Installation from source](https://cesium-ml.org/docs/install.html)


## License

`cesium` is released under the [3-clause BSD licence](https://github.com/cesium-ml/cesium/blob/main/LICENSE.txt).
